Malcolm
=======

|code_ci| |docs_ci| |coverage| |pypi_version|

Malcolm is a middlelayer framework that implements high level configure/run
behaviour of control system components like those used in continuous scans. 
This repository contains a Python implementation allowing the creation of 
Malcolm servers and clients. 

Documentation
-------------

Full documentation is available at https://dls-controls.github.io/pymalcolm

Source Code
-----------

Available from https://github.com/dls-controls/pymalcolm

Installation
------------
To install the latest release, type::

    pip install malcolm

To install the latest code directly from source, type::

    pip install git+git://github.com/dls-controls/pymalcolm.git

Changelog
---------

See `CHANGELOG`_

Contributing
------------

See `CONTRIBUTING`_

License
-------
APACHE License. (see `LICENSE`_)


.. |code_ci| image:: https://github.com/dls-controls/pymalcolm/workflows/Code%20CI/badge.svg?branch=master
    :target: https://github.com/dls-controls/pymalcolm/actions?query=workflow%3A%22Code+CI%22
    :alt: Code CI

.. |docs_ci| image:: https://github.com/dls-controls/pymalcolm/workflows/Docs%20CI/badge.svg?branch=master
    :target: https://github.com/dls-controls/pymalcolm/actions?query=workflow%3A%22Docs+CI%22
    :alt: Docs CI

.. |coverage| image:: https://codecov.io/gh/dls-controls/pymalcolm/branch/master/graph/badge.svg
    :target: https://codecov.io/gh/dls-controls/pymalcolm
    :alt: Test coverage

.. |pypi_version| image:: https://img.shields.io/pypi/v/malcolm.svg
    :target: https://pypi.python.org/pypi/malcolm/
    :alt: Latest PyPI version

.. _CHANGELOG:
    https://github.com/dls-controls/pymalcolm/blob/master/CHANGELOG.rst

.. _CONTRIBUTING:
    https://github.com/dls-controls/pymalcolm/blob/master/CONTRIBUTING.rst

.. _LICENSE:
    https://github.com/dls-controls/pymalcolm/blob/master/LICENSE
